@@ -17,16 +17,12 @@ CONFIG_SHELL=`/bin/sh -c 'echo $0'`
 case $CONFIG_SHELL in *.exe) ;; *) CONFIG_SHELL=$CONFIG_SHELL.exe ;; esac
 export CONFIG_SHELL
 #
-if ! grep -q __builtin_va_list $DJDIR/include/sys/djtypes.h ; then
-   echo "Your DJGPP installation have old incompatible $DJDIR/include/sys/djtypes.h"
-   echo "Please apply patch for this file included at end of `(cd ..; pwd)`/readme.DJGPP"
-   exit 1
-fi
-#
 conf_options="$target --prefix=/dev/env/DJDIR --disable-nls --disable-werror"
-conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++,ada"
-#conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++"
+#conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++,ada"
+conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++"
 conf_options="$conf_options --enable-libquadmath-support"
+conf_options="$conf_options --disable-lto"
+conf_options="$conf_options --disable-build-poststage1-with-cxx"
 #
 srcdir=`(cd $src && pwd) | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
 builddir=`pwd | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
