@@ -17,6 +17,10 @@ my $docdir = "gnu/gcc-$gcc_ver_s1";
 my $djver = getdjver();
 my ($djver_desc, $djreq);
 
+my $fver_find = "$gcc_ver";
+$fver_find =~ s/\./\\./g;
+print "fver_find=$fver_find\n";
+
 my @cpp_rename = (
 "bits/c++0x_warning.h:cxx0x_warning.hxx",
 "bits/exception_defines.h:_excptdef.h",
@@ -45,6 +49,8 @@ my @cpp_rename = (
 
 "debug/unordered_map:unordmap",
 "debug/unordered_set:unordset",
+"debug/safe_unordered_base.h:safe_unordered_base.h01",
+"debug/safe_unordered_container.h:safe_unordered_container.h02",
 
 "djgpp/bits/c++allocator.h:cxxallocator.h",
 "djgpp/bits/c++config.h:cxxconfig.h",
@@ -68,14 +74,13 @@ my @cpp_rename = (
 "ext/pb_ds/detail/hash_fn/sample_range_hashing.hpp:sr_hashing.hpp",
 "ext/pb_ds/detail/hash_fn/sample_ranged_hash_fn.hpp:sr_hash_fn.hpp",
 "ext/pb_ds/detail/hash_fn/sample_ranged_probe_fn.hpp:sr_probe_fn.hpp",
-"ext/pb_ds/detail/list_update_policy/counter_lu_metadata.hpp:clu_metadata.hpp",
-"ext/pb_ds/detail/list_update_policy/counter_lu_policy_imp.hpp:clu_policy_imp.hpp",
 "ext/pb_ds/detail/resize_policy/hash_load_check_resize_trigger_imp.hpp:hlcrt_imp.hpp",
 "ext/pb_ds/detail/resize_policy/hash_load_check_resize_trigger_size_base.hpp:hlcrt_size_base.hpp",
 "ext/pb_ds/detail/resize_policy/sample_resize_policy.hpp:sr_policy.hpp",
 "ext/pb_ds/detail/resize_policy/sample_resize_trigger.hpp:sr_trigger.hpp",
-"ext/pb_ds/detail/trie_policy/sample_trie_e_access_traits.hpp:ste_access_traits.hpp",
 "ext/pb_ds/detail/trie_policy/sample_trie_node_update.hpp:stn_update.hpp",
+"ext/pb_ds/detail/pat_trie_/pat_trie_.hpp:pat_trie.h01",
+"ext/pb_ds/detail/pat_trie_/pat_trie_base.hpp:pat_trie.h02",
 "ext/vstring_fwd.h:vstr_fwd.h",
 "ext/vstring_util.h:vstr_util.h",
 
@@ -116,8 +121,7 @@ my @rename_list = (
 "lib/libsupc++.a:#gcc_lib#/libsupcxx.a",
 "lib/libstdcxx.la:#gcc_lib#/libstdcxx.la",
 "lib/libstdcxx.a:#gcc_lib#/libstdcxx.a",
-"libstdcxx_a-gdb.py:#gcc_lib#/libstdcxx_a-gdb-py",
-"lib/libstdcxx.a-gdb.py:##libstdcxx_a-gdb.py",
+"lib/libstdcxx.a-gdb.py:##/libstdcxx_a-gdb-py",
 "lib/libgf95begin.a:#gcc_lib#/libgf95begin.a",
 "lib/libgfortran.a:#gcc_lib#/libgfortran.a",
 "lib/libgf95begin.la:#gcc_lib#/libgf95begin.la",
@@ -305,18 +309,6 @@ sub objc_rename_proc
 
     my @objc_rename =
       (
-       "objc/deprecated/struct_objc_category.h:struct_objc_category.h1",
-       "objc/deprecated/struct_objc_class.h:struct_objc_class.h2",
-       "objc/deprecated/struct_objc_ivar.h:struct_objc_ivar.h3",
-       "objc/deprecated/struct_objc_ivar_list.h:struct_objc_ivar_list.h4",
-       "objc/deprecated/struct_objc_method.h:struct_objc_method.h5",
-       "objc/deprecated/struct_objc_method_list.h:struct_objc_method_list.h6",
-       "objc/deprecated/struct_objc_module.h:struct_objc_module.h7:",
-       "objc/deprecated/struct_objc_protocol.h:struct_objc_protocol.h8",
-       "objc/deprecated/struct_objc_protocol_list.h:struct_objc_protocol_list.h9",
-       "objc/deprecated/struct_objc_selector.h:struct_objc_selector.h10",
-       "objc/deprecated/struct_objc_static_instances.h:struct_objc_static_instances.h11",
-       "objc/deprecated/struct_objc_symtab.h:struct_objc_symtab.h12",
        "quadmath_weak.h:quadmath_weak.h1"
       );
 
@@ -686,6 +678,7 @@ sub mk_manifest
     my @gforfiles = (
         'bin/gfortran\.exe', 'info/gfortran.info',
         '/libgf', '/f951\.exe', 'manifest/gfor',
+	'/libcaf_single.a',
         '/cat1/gfortran'
     );
 
@@ -697,10 +690,13 @@ sub mk_manifest
 
     my @gccfiles = (
         'bin/gcc\.exe', 'bin/cpp\.exe', 'bin/gcov\.exe', 'bin/gccbug',
+        'bin/gcc-(?:ar|nm|ranlib)\.exe',
         'include/ssp/', 'info/(?:cpp|gcc|libquadmath)', '/djgpp\.ver$',
         '/include/(?:am|bm|em|m|nm|pm|sm|tm|xm)mintrin',
         '/include/(?:cpuid|float|iso646|mm_malloc|mm3dnow|mmintcommon)\.h$',
         '/include/(?:avx|imm|wmm|x86|bmi|tbm)intrin\.h$',
+        '/include/(?:avx2|bmi2|f16c|fma|lzcnt)intrin.\h$',
+        '/include/std(?:align|noreturn)\.h$',
         '/include/quadmath(?:|_weak).h',
         '/include/(?:stdarg|stdbool|stddef|stdfix|tgmath|unwind|varargs)\.h$',
         '/include/header.gcc$',
@@ -733,8 +729,23 @@ sub mk_manifest
     my $NF=0;
     while (<$fd>)
     {
-        chomp; s:^\./::;
+        chomp;
+	s:^\./::;
         next if (! m/\//);
+
+        if ($_ =~ m|/$fver_find/|)
+        {
+            my $old_name = $_;
+            my $new_name = $_;
+            $new_name =~ s|/$fver_find/|/$gcc_ver_s1/|g;
+            print "WARNING: GCC full version detected - renaming:\n";
+            print "   $old_name ==> $new_name\n";
+            my $dir = dirname($new_name);
+            system("mkdir -pv $dir");
+            rename($old_name, $new_name);
+            $_ = $new_name;
+        }
+
         $status{$_} = "unknown";
         $NF++;
     }
